package de.hftstuttgart.unifiedticketing.core;

import de.hftstuttgart.unifiedticketing.exceptions.AssertionException;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.*;
import static org.mockito.Mockito.*;

public class TicketSystemBuilderTest
{
    public TicketSystemBuilder instance;

    @BeforeEach
    public void initBeforeEach()
    {
        instance = mock(TicketSystemBuilder.class, withSettings().useConstructor().defaultAnswer(CALLS_REAL_METHODS));
    }

    @Test
    public void testWithBaseUrl()
    {
        String expected = "some.url.tld";

        instance.withBaseUrl(expected);
        assertEquals(expected, instance.baseUrl);

        assertAll(
            () -> assertThrows(AssertionException.class, () -> instance.withBaseUrl("http://urlwithprefix.com")),
            () -> assertThrows(AssertionException.class, () -> instance.withBaseUrl("https://urlwithprefix.com"))
        );
    }

    @Test
    public void testFluentApi()
    {
        TicketSystemBuilder before = instance;
        TicketSystemBuilder after = instance
            .withBaseUrl("teststring");

        assertSame(before, after);
    }
}
